Llicència Ğ1 - v0.2.9
====================

:Date: 2017-04-04 12:59
:Modified: 2023-01-01 18:33

**Llicència de la moneda i compromís de responsabilitat.**

Qualsevol certificació d'un nou membre de Ğ1 Ha d'anar en primer lloc acompanyada de la transmissió d'aquesta llicència de la moneda Ğ1, on el certificador ha d'assegurar-se que ha sigut estudiada, entesa i acceptada per la persona que serà certificada.

Cualquier evento de encuentro relacionado con Ğ1 debe ir acompañado de la transmisión de esta licencia, que puede leerse en voz alta y transmitirse por cualquier medio.

Red de confianza Ğ1 (RdC Ğ1)
------------------------------

** Aviso de advertencia :** Certificar no significa que simplemente has visto físicamente a la persona candidata. Es asegurar a la comunidad Ğ1 que la conoces lo suficientemente bien y que sabrás cómo contactarla y localizarla fácilmente, ser capaz de identificar una posible cuenta falsa o duplicada realizada por alguien que has certificado, u otro tipo de problema, efectuando verificaciones con la comunidad que detecten el problema. La seguridad de la Red de Confianza es descentralizada.

**Consejos fuertemente recomendados**

Conocer bien a una persona significa que puedes comunicarte con ella por varios medios distintos (físicos, electrónicos, etc ...) pero también que conoces a varias personas que también la conocen bien y, por lo tanto, pueden contactar con ella igualmente. Además si no conoces bien a nadie de quienes ya le han certificado, es una clara indicación de que no conoces bien a la persona; una certificación de este tipo provoca una alerta hacia toda la comunidad Ğ1. En caso de conocimiento insuficiente, es importante NO certificar.

Nunca certifiques solo/a, sino acompáñate por al menos otro/a miembro de la RdC Ğ1 para evitar cualquier error de manejo. En caso de error, advierte a quienes ya son miembros de la RdC Ğ1 inmediatamente.

Antes de cualquier certificación, asegúrate de verificar si su cuenta (tanto si es nueva candidatura o ya miembro) ha recibido ya una o más certificaciones. Si es necesario, solicite información para ponerte en contacto con quienes ya le hayan certificado para verificar juntos/as que conocéis bien la persona en cuestión concerniente, así como su llave pública correspondiente.

Comprueba que la persona a ser certificada domina bien el manejo de su cuenta: una buena manera de comprobar esto es transferir unas Ğ1 a la cuenta destino, y luego pedir la devolución a tu propia cuenta. Esto asegura el buen manejo por quien va a ser certificado, de su llave privada.

Comprueba que tus contactos hayan estudiado y comprendido la licencia Ğ1 actualizada.

Si te percatas de que un/a certificador/a real o potencial de la cuenta candidata no conoce a la persona interesada, avisa inmediatamente a quien tenga experiencia en el tema de tus contactos en la RdC Ğ1, para que la RdC Ğ1 verifique el proceso de validación.

Cuando eres miembro de la RdC Ğ1 y estás a punto de certificar una cuenta:


** Estás seguro de: **

1°) Conocer suficientemente bien a quien declara poseer esta llave pública (cuenta candidata a miembro). Lea los consejos fuertemente recomendados más arriba para asegurarte de que la "conoces bien".

2°) Haber comprobado personalmente con esa persona de que se trata de esa llave pública que está a punto de certificar.

3°) Haber verificado con la persona interesada, que ha generado y guardado su documento o archivo de revocación de cuenta Duniter que le permitirá, si es necesario, desactivar su estado de miembro y cocreación (en caso de robo de las contraseñas, cambio de seudónimo, cuenta creada incorrectamente, etc.).

4a°) Para verificar el paso 2, para asegurarte de que la persona humana que conoces bien posee esa llave pública, es recomendable hacer esa validación in situ físicamente.

4b°) O bien se puede realizar la validación de forma remota de la llave pública, comunicándola por diferentes medios, como correo ordinario, electrónico, redes sociales, foro, videoconferencia, llamada telefónica (reconociendo la voz). Si alguien hackeara una cuenta de correo electrónico o una cuenta en un foro, es mucho más difícil imaginar que pueda hackear cuatro medios de comunicación separados, e imitar la apariencia (vídeo) e incluso la voz de alguien.

La 4a° es preferible a la 4b° mientras que los puntos 1°, 2° y 3° son ante todo indispensables.


**Reglas abreviadas de la RdC :**

Cada miembro tiene una reserva de 100 certificaciones posibles, que solo pueden hacerse efectivas a razón de 1 certificación cada 5 días.

Válida durante 2 meses, una certificación se toma en consideración definitivamente para una nueva candidatura de membresía si esta persona recibe al menos otras 4 certificaciones que cumplen la regla de distancia durante esos 2 meses, de lo contrario, el proceso de candidatura deberá reiniciarse sin perder acceso a la cuenta.

Para convertirse en nuevo/a miembro de la RdC Ğ1 es necesario obtener 5 certificaciones y estar a una distancia de <= 5 pasos con como mínimo un 80% del total de miembros referentes de la RdC.

Alguien es miembro referente de la RdC Ğ1 cuando ha recibido y también emitido al menos Y[N] certificaciones donde N es el total de miembros en la RdC e Y[N] = techo N^(1/5). Ejemplos:

* Para 1024 < N ≤ 3125 se obtiene que Y[N] = 5
* Para 7776 < N ≤ 16807 se obtiene que Y[N] = 7
* para 59049 < N ≤ 100.000 se obtiene que Y[N] = 10

Una vez que alguien es nuevo/a miembro de la RdC Ğ1, sus certificaciones serán válidas durante 2 años.

Para seguir siendo miembro, se debe renovar el acuerdo regularmente mediante la llave privada (cada 12 meses) y asegurarse de que siempre se tenga al menos 5 certificaciones válidas después de los 2 años.

Moneda Ğ1
----------

Ğ1 se genera a través de un Dividendo Universal (DU) para cada ser humano miembro de la Red de Confianza Ğ1, de la siguiente forma:

* 1 DU por persona y por día.

La cantidad en Ğ1 del DU diario es idéntica hasta pasado cada equinoccio(cada 6 meses) cuando se re-evaluará el DU según la fórmula :

* DU diario (próximo equinoccio) = DU diario (equinoccio) + c² (M/N)(equinoccio) / (15778800 segundos)

Teniendo como constantes:

* c = 4,88% / equinoccio
* DU(0) = 10,00 Ğ1

Y como variables :

* *M* la masa monetaria total en el equinoccio
* *N* el número de miembros el día del equinoccio

Software Ğ1 y licencia Ğ1
--------------------------

El software Ğ1 que permita a los usuarios administrar su uso de Ğ1 debe transmitir esta licencia y todos los parámetros técnicos de la moneda Ğ1 y de la RdC Ğ1 que han sido configurados en el bloque 0 de Ğ1. El software que no cumpla con estas obligaciones de la licencia no es compatible con Ğ1.

Para más detalle en los aspectos técnicos, es posible consultar directamente el código de Duniter, que es un software libre así como los datos de la cadena de bloques (blockchain) Ğ1, recuperándolos a través de una instancia (o nodo) de Duniter Ğ1.

Más información en el sitio web del equipo Duniter https://www.duniter.org
